@@ -179,6 +179,15 @@ class Device(object):
         """Get values of inels and ha type."""
         return self.__values
 
+    @property
+    def last_values(self) -> DeviceValue:
+        """Get last value of the device
+
+        Returns:
+            DeviceValue: latest values in many formats
+        """
+        return self.__get_value(self.__mqtt.last_value(self.__set_topic))
+
     @property
     def mqtt(self) -> InelsMqtt:
         """Instnace of broker."""
